@@ -36,6 +36,10 @@
 #include <X11/extensions/Xsp.h>
 #endif /* HAVE_LIBXSP */
 
+#if defined(HAVE_LIBOSSO)
+#include <libosso.h>
+#endif
+
 //extern "C"
 //{
 int main(int argc, char **argv)
@@ -46,6 +50,26 @@ int main(int argc, char **argv)
 }
 //}
 
+#if defined(HAVE_LIBOSSO)
+static osso_context_t *ossoContext;
+
+static void maemoExit(void)
+{
+    if (ossoContext)
+    {
+        osso_deinitialize(ossoContext);
+        ossoContext = NULL;
+    }
+}
+
+static void maemoInit(void)
+{
+    putenv("SDL_VIDEO_X11_WMCLASS=" APPNAME);
+    ossoContext = osso_initialize("org.unrealvoodoo.nspeed", "1.1", TRUE, NULL);
+    atexit(maemoExit);
+}
+#endif /* HAVE_LIBOSSO */
+
 SDLFramework::SDLFramework():
         screen(0),
         gameScreen(0),
@@ -110,11 +134,9 @@ int SDLFramework::run(int argc, char **argv)
     bool useXsp = false;
 #endif
 
-#if defined(APPNAME)
-    static char wmClass[128];
-    snprintf(wmClass, sizeof(wmClass), "SDL_VIDEO_X11_WMCLASS=%s", APPNAME);
-    putenv(wmClass);
-#endif
+#if defined(HAVE_LIBOSSO)
+    maemoInit();
+#endif /* HAVE_LIBOSSO */
 
 #if defined(PREFIX) && defined(APPNAME)
     strncpy(dataDir, PREFIX "/share/games/" APPNAME, sizeof(dataDir));
@@ -197,6 +219,7 @@ int SDLFramework::run(int argc, char **argv)
         else
         {
             SDL_ShowCursor(0);
+            SDL_EnableUNICODE(SDL_ENABLE);
 #if defined(HAVE_LIBXSP)
             if (scaleFactor == 2)
             {
@@ -804,3 +827,8 @@ const char *SDLFramework::findResource(const char *name, bool mustExist, bool wr
     return resourcePath;
 }
 
+void SDLFramework::showTaskSwitcher()
+{
+    // Pretty lazy, huh?
+    system("dbus-send --type=signal --session /com/nokia/hildon_desktop com.nokia.hildon_desktop.exit_app_view");
+}
